@@ -3,9 +3,8 @@ import warnings
 from functools import wraps
 from typing import Callable, TypeVar
 
-from typing_extensions import ParamSpec
-
 import pydantic
+from typing_extensions import ParamSpec
 
 from souswift_core.dtos import Model
 
@@ -13,6 +12,7 @@ T = TypeVar('T')
 P = ParamSpec('P')
 ModelT = TypeVar('ModelT', bound=Model)
 
+
 def deprecated(func: Callable[P, T]) -> Callable[P, T]:
     @wraps(func)
     def inner(*args: P.args, **kwargs: P.kwargs) -> T:
@@ -34,7 +34,9 @@ async def as_async(
 
 def get_optional_model(model: type[ModelT], *exclude: str) -> type[ModelT]:
     edit_dto = pydantic.create_model(
-        f'Optional{model.__name__}', __base__=model, __module__=model.__module__
+        f'Optional{model.__name__}',
+        __base__=model,
+        __module__=model.__module__,
     )
     for field in edit_dto.__fields__.values():
         field.required = False
